cooklang-chef 0.2.0

CLI to manage cooklang recipes
cooklang-chef-0.2.0 is not a library.

cooklang-chef

Crates.io Crates.io

A CLI utility to manage your cooklang recipes.

Install it with[^1]:

cargo install cooklang-chef

[^1]: This method currently has a problem. A dependency has a bug which is solved but pending a release. Until then error colors won't work. If that is a big problem for you, manually cloning the repo and compiling will work.

Entire cooklang-rs project: https://github.com/Zheoni/cooklang-rs