pub struct CookArgs {Show 16 fields
pub profile: OptimisationProfile,
pub command: CommandArg,
pub default_features: DefaultFeatures,
pub all_features: AllFeatures,
pub features: Option<HashSet<String>>,
pub unstable_features: Option<HashSet<String>>,
pub target: Option<Vec<String>>,
pub target_dir: Option<PathBuf>,
pub target_args: TargetArgs,
pub manifest_path: Option<PathBuf>,
pub package: Option<Vec<String>>,
pub workspace: bool,
pub offline: bool,
pub timings: bool,
pub no_std: bool,
pub bin: Option<String>,
}
command: CommandArg
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.