pub struct Skeleton {
pub manifests: Vec<Manifest>,
pub config_file: Option<String>,
pub lock_file: Option<String>,
pub rust_toolchain_file: Option<(RustToolchainFile, String)>,
}Fields
manifests: Vec<Manifest>config_file: Option<String>lock_file: Option<String>rust_toolchain_file: Option<(RustToolchainFile, String)>Implementations
Sourceimpl Skeleton
impl Skeleton
Sourcepub fn derive<P: AsRef<Path>>(
base_path: P,
member: Option<String>,
) -> Result<Self, Error>
pub fn derive<P: AsRef<Path>>( base_path: P, member: Option<String>, ) -> Result<Self, Error>
Find all Cargo.toml files in base_path by traversing sub-directories recursively.
Sourcepub fn build_minimum_project(
&self,
base_path: &Path,
no_std: bool,
) -> Result<(), Error>
pub fn build_minimum_project( &self, base_path: &Path, no_std: bool, ) -> Result<(), Error>
Given the manifests in the current skeleton, create the minimum set of files required to
have a valid Rust project (i.e. write all manifests to disk and create dummy lib.rs,
main.rs and build.rs files where needed).
This function should be called on an empty canvas - i.e. an empty directory apart from the recipe file used to restore the skeleton.
Sourcepub fn remove_compiled_dummies<P: AsRef<Path>>(
&self,
base_path: P,
profile: OptimisationProfile,
target: Option<Vec<String>>,
target_dir: Option<PathBuf>,
) -> Result<(), Error>
pub fn remove_compiled_dummies<P: AsRef<Path>>( &self, base_path: P, profile: OptimisationProfile, target: Option<Vec<String>>, target_dir: Option<PathBuf>, ) -> Result<(), Error>
Scan the target directory and remove all compilation artifacts for libraries and build
scripts from the current workspace.
Given the usage of dummy lib.rs and build.rs files, keeping them around leads to funny
compilation errors.