pub struct CookArgs {
pub profile: OptimisationProfile,
pub default_features: DefaultFeatures,
pub features: Option<HashSet<String>>,
pub target: Option<String>,
pub target_dir: Option<PathBuf>,
pub target_args: TargetArgs,
pub manifest_path: Option<PathBuf>,
pub package: Option<String>,
pub workspace: bool,
pub offline: bool,
}
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.