[−][src]Struct chef::Skeleton
Fields
manifests: Vec<Manifest>lock_file: Option<String>Implementations
impl Skeleton[src]
pub fn derive<P: AsRef<Path>>(base_path: P) -> Result<Self, Error>[src]
Find all Cargo.toml files in base_path by traversing sub-directories recursively.
pub fn build_minimum_project(&self, base_path: &Path) -> Result<(), Error>[src]
Given the manifests in the current skeleton, create the minimum set of files required to
have a valid Rust project (i.e. write all manifests to disk and create dummy lib.rs,
main.rs and build.rs files where needed).
This function should be called on an empty canvas - i.e. an empty directory apart from the recipe file used to restore the skeleton.
pub fn remove_compiled_dummies<P: AsRef<Path>>(
&self,
base_path: P,
profile: OptimisationProfile,
target: Option<String>,
target_dir: Option<PathBuf>
) -> Result<(), Error>[src]
&self,
base_path: P,
profile: OptimisationProfile,
target: Option<String>,
target_dir: Option<PathBuf>
) -> Result<(), Error>
Scan the target directory and remove all compilation artifacts for libraries and build
scripts from the current workspace.
Given the usage of dummy lib.rs and build.rs files, keeping them around leads to funny
compilation errors.