[][src]Struct chef::Skeleton

pub struct Skeleton {
    pub manifests: Vec<Manifest>,
    pub lock_file: Option<String>,
}

Fields

manifests: Vec<Manifest>lock_file: Option<String>

Implementations

impl Skeleton[src]

pub fn derive<P: AsRef<Path>>(base_path: P) -> Result<Self, Error>[src]

Find all Cargo.toml files in base_path by traversing sub-directories recursively.

pub fn build_minimum_project(&self) -> Result<(), Error>[src]

Given the manifests in the current skeleton, create the minimum set of files required to have a valid Rust project (i.e. write all manifests to disk and create dummy lib.rs, main.rs and build.rs files where needed).

This function should be called on an empty canvas - i.e. an empty directory apart from the recipe file used to restore the skeleton.